Publications
============

How to cite
-----------

This library is scientific software, and can be cited with the following
reference:

    *Larralde M.* **Developing Python and Rust libraries to improve the ontology ecosystem**
    *\[version 1; not peer reviewed\].* F1000Research 2019, 8(ISCB Comm J):1500 (poster)
    (`https://doi.org/10.7490/f1000research.1117405.1 <https://doi.org/10.7490/f1000research.1117405.1>`_)


Citations
---------

``fastobo`` has been used in the following research works:

- Bittremieux, W., Levitsky, L., Pilz, M., Sachsenberg, T., Huber, F., Wang, M., & Dorrestein, P. C. (2023). Unified and Standardized Mass Spectrometry Data Processing in Python Using spectrum_utils. Journal of Proteome Research, 22(2), 625–631. https://doi.org/10.1021/acs.jproteome.2c00632
- Glauer, M. (2024). Knowledge and learning: Synergies between ontologies and machine learning. https://doi.org/10.25673/116961
